# Matchmaker
A short code for creating matched pairs from groups.

Visit the active code via :
https://github.com/richardtjornhammar/counterpartner

Visit the published code : 
https://doi.org/

Cite using :
DOI: 

Install with :
pip install counterpartner
